@@ -49,6 +49,7 @@ BaseTableIterator::BaseTableIterator (BaseTable* btp,
 				      int option)
 : lastRow_p (0),
   nrkeys_p  (keys.nelements()),
+  keyChangeAtLastNext_p(""),
   lastVal_p (keys.nelements()),
   curVal_p  (keys.nelements()),
   colPtr_p  (keys.nelements()),
@@ -147,6 +148,8 @@ BaseTable* BaseTableIterator::next()
 	    colPtr_p[i]->get (lastRow_p, curVal_p[i]);
 	    if (cmpObj_p[i]->comp (curVal_p[i], lastVal_p[i])  != 0) {
 		match = False;
+		// update so users can see which key changed
+		keyChangeAtLastNext_p=colPtr_p[i]->columnDesc().name();   
 		break;
 	    }
 	}
@@ -155,6 +158,11 @@ BaseTable* BaseTableIterator::next()
 	}
 	itp->addRownr (lastRow_p);
     }
+
+    // If we've reached the end of the table, clear the keyCh_p
+    if (lastRow_p==nr)
+      keyChangeAtLastNext_p=String();
+
     //# Adjust rownrs in case source table is already a RefTable.
     Vector<uInt>& rownrs = *(itp->rowStorage());
     sortTab_p->adjustRownrs (itp->nrow(), rownrs, False);
