@@ -203,6 +203,9 @@ public:
     void operator++(int);
     // </group>
 
+    // Report Name of slowest column that changes at end of current iteration
+    const String& keyChangeAtLastNext() const;
+
     // Get the current group.
     Table table() const;
 
